@@ -15,6 +15,8 @@ import logging
 import random
 import requests
 
+from client.utils.printer import print_error
+
 log = logging.getLogger(__name__)
 
 #####################
@@ -29,8 +31,8 @@ class HintingProtocol(protocol_models.Protocol):
     HINT_ENDPOINT = 'api/hints'
     SMALL_EFFORT = 2
     WAIT_ATTEMPTS = 5
-    SUPPORTED_ASSIGNMENTS = ['cal/cs61a/su16/hw08', 'cal/cs61a/su16/lab10', 'cal/cs61a/fa16/hw09',
-                             'cal/cs61a/sp17/hw07']
+    SUPPORTED_ASSIGNMENTS = ['cal/cs61a/fa17/hw09', 'cal/cs61a/fa17/hw10',
+            'cal/cs61a/fa17/lab10']
 
     def run(self, messages):
         """Determine if a student is elgible to recieve a hint. Based on their
@@ -124,7 +126,7 @@ class HintingProtocol(protocol_models.Protocol):
                 except (requests.exceptions.RequestException, requests.exceptions.BaseHTTPError):
                     log.debug("Network error while fetching hint", exc_info=True)
                     hint_info['fetch_error'] = True
-                    print("\r\nNetwork Error while generating hint. Try again later")
+                    print_error("\r\nNetwork Error while generating hint. Try again later")
                     response = None
                     continue
 
